@@ -33,7 +33,7 @@ import (
 	openshiftrouteclientset "github.com/openshift/client-go/route/clientset/versioned"
 	openshiftsecurityclientset "github.com/openshift/client-go/security/clientset/versioned"
 	"github.com/pkg/errors"
-	appsv1 "k8s.io/api/apps/v1beta2"
+	appsv1 "k8s.io/api/apps/v1"
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/api/extensions/v1beta1"
 	v1betaextensions "k8s.io/api/extensions/v1beta1"
@@ -345,9 +345,28 @@ func (c *Client) DeleteHashedConfigMap(newHash, prefix string) error {
 	return nil
 }
 
+func (c *Client) DeleteHashedSecret(newHash, prefix string) error {
+	ls := "monitoring.openshift.io/name=" + prefix + ",monitoring.openshift.io/hash!=" + newHash
+	configMaps, err := c.KubernetesInterface().CoreV1().Secrets(c.namespace).List(metav1.ListOptions{
+		LabelSelector: ls,
+	})
+	if err != nil {
+		return errors.Wrapf(err, "error listing secrets with label selector %s", ls)
+	}
+
+	for i := range configMaps.Items {
+		err := c.KubernetesInterface().CoreV1().Secrets(c.namespace).Delete(configMaps.Items[i].Name, &metav1.DeleteOptions{})
+		if err != nil {
+			return errors.Wrapf(err, "error deleting secret: %s", configMaps.Items[i].Name)
+		}
+	}
+
+	return nil
+}
+
 func (c *Client) DeleteDeployment(d *appsv1.Deployment) error {
 	p := metav1.DeletePropagationForeground
-	err := c.kclient.AppsV1beta2().Deployments(d.GetNamespace()).Delete(d.GetName(), &metav1.DeleteOptions{PropagationPolicy: &p})
+	err := c.kclient.AppsV1().Deployments(d.GetNamespace()).Delete(d.GetName(), &metav1.DeleteOptions{PropagationPolicy: &p})
 	if apierrors.IsNotFound(err) {
 		return nil
 	}
@@ -387,7 +406,7 @@ func (c *Client) DeletePrometheus(p *monv1.Prometheus) error {
 
 func (c *Client) DeleteDaemonSet(d *v1beta1.DaemonSet) error {
 	orphanDependents := false
-	err := c.kclient.AppsV1beta2().DaemonSets(d.GetNamespace()).Delete(d.GetName(), &metav1.DeleteOptions{OrphanDependents: &orphanDependents})
+	err := c.kclient.AppsV1().DaemonSets(d.GetNamespace()).Delete(d.GetName(), &metav1.DeleteOptions{OrphanDependents: &orphanDependents})
 	if apierrors.IsNotFound(err) {
 		return nil
 	}
@@ -511,7 +530,7 @@ func (c *Client) WaitForAlertmanager(a *monv1.Alertmanager) error {
 }
 
 func (c *Client) CreateOrUpdateDeployment(dep *appsv1.Deployment) error {
-	d, err := c.kclient.AppsV1beta2().Deployments(dep.GetNamespace()).Get(dep.GetName(), metav1.GetOptions{})
+	d, err := c.kclient.AppsV1().Deployments(dep.GetNamespace()).Get(dep.GetName(), metav1.GetOptions{})
 
 	if apierrors.IsNotFound(err) {
 		err = c.CreateDeployment(dep)
@@ -531,7 +550,7 @@ func (c *Client) CreateOrUpdateDeployment(dep *appsv1.Deployment) error {
 }
 
 func (c *Client) CreateDeployment(dep *appsv1.Deployment) error {
-	d, err := c.kclient.AppsV1beta2().Deployments(dep.GetNamespace()).Create(dep)
+	d, err := c.kclient.AppsV1().Deployments(dep.GetNamespace()).Create(dep)
 	if err != nil {
 		return err
 	}
@@ -540,7 +559,7 @@ func (c *Client) CreateDeployment(dep *appsv1.Deployment) error {
 }
 
 func (c *Client) UpdateDeployment(dep *appsv1.Deployment) error {
-	updated, err := c.kclient.AppsV1beta2().Deployments(dep.GetNamespace()).Update(dep)
+	updated, err := c.kclient.AppsV1().Deployments(dep.GetNamespace()).Update(dep)
 	if err != nil {
 		return err
 	}
@@ -551,7 +570,7 @@ func (c *Client) UpdateDeployment(dep *appsv1.Deployment) error {
 func (c *Client) WaitForDeploymentRollout(dep *appsv1.Deployment) error {
 	var lastErr error
 	if err := wait.Poll(time.Second, deploymentCreateTimeout, func() (bool, error) {
-		d, err := c.kclient.AppsV1beta2().Deployments(dep.GetNamespace()).Get(dep.GetName(), metav1.GetOptions{})
+		d, err := c.kclient.AppsV1().Deployments(dep.GetNamespace()).Get(dep.GetName(), metav1.GetOptions{})
 		if err != nil {
 			return false, err
 		}
@@ -573,7 +592,7 @@ func (c *Client) WaitForDeploymentRollout(dep *appsv1.Deployment) error {
 func (c *Client) WaitForStatefulsetRollout(sts *appsv1.StatefulSet) error {
 	var lastErr error
 	if err := wait.Poll(time.Second, deploymentCreateTimeout, func() (bool, error) {
-		d, err := c.kclient.AppsV1beta2().StatefulSets(sts.GetNamespace()).Get(sts.GetName(), metav1.GetOptions{})
+		d, err := c.kclient.AppsV1().StatefulSets(sts.GetNamespace()).Get(sts.GetName(), metav1.GetOptions{})
 		if err != nil {
 			return false, err
 		}
@@ -592,6 +611,40 @@ func (c *Client) WaitForStatefulsetRollout(sts *appsv1.StatefulSet) error {
 	return nil
 }
 
+func (c *Client) WaitForSecret(s *v1.Secret) (*v1.Secret, error) {
+	var result *v1.Secret
+	var lastErr error
+	if err := wait.Poll(1*time.Second, 5*time.Minute, func() (bool, error) {
+		var err error
+		result, err = c.kclient.CoreV1().Secrets(s.Namespace).Get(s.Name, metav1.GetOptions{})
+
+		if apierrors.IsNotFound(err) {
+			lastErr = err
+			return false, nil
+		}
+
+		if err != nil {
+			return false, err
+		}
+
+		for _, v := range result.Data {
+			if len(v) == 0 {
+				lastErr = errors.New("secret contains no data")
+				return false, nil
+			}
+		}
+
+		return true, nil
+	}); err != nil {
+		if err == wait.ErrWaitTimeout && lastErr != nil {
+			err = lastErr
+		}
+		return nil, errors.Wrapf(err, "waiting for secret %s", s.GetName())
+	}
+
+	return result, nil
+}
+
 func (c *Client) WaitForRouteReady(r *routev1.Route) (string, error) {
 	host := ""
 	var lastErr error
@@ -622,7 +675,7 @@ func (c *Client) WaitForRouteReady(r *routev1.Route) (string, error) {
 }
 
 func (c *Client) CreateOrUpdateDaemonSet(ds *appsv1.DaemonSet) error {
-	_, err := c.kclient.AppsV1beta2().DaemonSets(ds.GetNamespace()).Get(ds.GetName(), metav1.GetOptions{})
+	_, err := c.kclient.AppsV1().DaemonSets(ds.GetNamespace()).Get(ds.GetName(), metav1.GetOptions{})
 	if apierrors.IsNotFound(err) {
 		err = c.CreateDaemonSet(ds)
 		return errors.Wrap(err, "creating DaemonSet object failed")
@@ -636,7 +689,7 @@ func (c *Client) CreateOrUpdateDaemonSet(ds *appsv1.DaemonSet) error {
 }
 
 func (c *Client) CreateDaemonSet(ds *appsv1.DaemonSet) error {
-	d, err := c.kclient.AppsV1beta2().DaemonSets(ds.GetNamespace()).Create(ds)
+	d, err := c.kclient.AppsV1().DaemonSets(ds.GetNamespace()).Create(ds)
 	if err != nil {
 		return err
 	}
@@ -645,7 +698,7 @@ func (c *Client) CreateDaemonSet(ds *appsv1.DaemonSet) error {
 }
 
 func (c *Client) UpdateDaemonSet(ds *appsv1.DaemonSet) error {
-	updated, err := c.kclient.AppsV1beta2().DaemonSets(ds.GetNamespace()).Update(ds)
+	updated, err := c.kclient.AppsV1().DaemonSets(ds.GetNamespace()).Update(ds)
 	if err != nil {
 		return err
 	}
@@ -656,7 +709,7 @@ func (c *Client) UpdateDaemonSet(ds *appsv1.DaemonSet) error {
 func (c *Client) WaitForDaemonSetRollout(ds *appsv1.DaemonSet) error {
 	var lastErr error
 	if err := wait.Poll(time.Second, deploymentCreateTimeout, func() (bool, error) {
-		d, err := c.kclient.AppsV1beta2().DaemonSets(ds.GetNamespace()).Get(ds.GetName(), metav1.GetOptions{})
+		d, err := c.kclient.AppsV1().DaemonSets(ds.GetNamespace()).Get(ds.GetName(), metav1.GetOptions{})
 		if err != nil {
 			return false, err
 		}
@@ -986,5 +1039,23 @@ func (c *Client) CRDReady(crd *extensionsobj.CustomResourceDefinition) (bool, er
 }
 
 func (c *Client) StatusReporter() *StatusReporter {
-	return NewStatusReporter(c.oscclient.Config().ClusterOperators(), "monitoring", c.namespace, c.version)
+	return NewStatusReporter(c.oscclient.ConfigV1().ClusterOperators(), "monitoring", c.namespace, c.version)
+}
+
+func (c *Client) DeleteRoleBinding(binding *rbacv1.RoleBinding) error {
+	err := c.kclient.RbacV1().RoleBindings(binding.Namespace).Delete(binding.GetName(), &metav1.DeleteOptions{})
+	if apierrors.IsNotFound(err) {
+		return nil
+	}
+
+	return err
+}
+
+func (c *Client) DeleteRole(role *rbacv1.Role) error {
+	err := c.kclient.RbacV1().Roles(role.Namespace).Delete(role.GetName(), &metav1.DeleteOptions{})
+	if apierrors.IsNotFound(err) {
+		return nil
+	}
+
+	return err
 }
